==> mongodb-src-r4.4.2.tar.gz: mongodb-src-r4.4.2/jstests/replsets/maintenance_non-blocking.js <==
// This test ensures that the replSetMaintenance command will not block, nor block-on, a db write
doTest = function() {
    "use strict";
    var replTest = new ReplSetTest({name: 'testSet', nodes: 2});
    var nodes = replTest.startSet();
    replTest.initiate();

    var m = replTest.getPrimary();
    var mColl = m.getDB("test").maint;
    var s = replTest.getSecondary();
    var sDB = s.getDB("test");
    var sColl = sDB.maint;

    var status = assert.commandWorked(sDB.adminCommand("replSetGetStatus"));
    printjson(status);

    print("******* fsyncLock'n secondary ************* ");
    s.getDB("admin").fsyncLock();

    // save some records
    var len = 100;
    for (var i = 0; i < len; ++i) {
        assert.commandWorked(mColl.save({a: i}));
    }

    print("******* replSetMaintenance called on secondary ************* ");
    assert.commandWorked(sDB.adminCommand("replSetMaintenance"));

    var ismaster = assert.commandWorked(sColl.runCommand("ismaster"));
    assert.eq(false, ismaster.ismaster);
    assert.eq(false, ismaster.secondary);

    print("******* writing to primary ************* ");
    assert.commandWorked(mColl.save({_id: -1}));
    printjson(sDB.currentOp());
    assert.neq(null, mColl.findOne());

    var ismaster = assert.commandWorked(sColl.runCommand("ismaster"));
    assert.eq(false, ismaster.ismaster);
    assert.eq(false, ismaster.secondary);

    print("******* fsyncUnlock'n secondary ************* ");
    sDB.fsyncUnlock();

    print("******* unset replSetMaintenance on secondary ************* ");
    assert.commandWorked(sDB.adminCommand({replSetMaintenance: 0}));
    replTest.stopSet();
};

doTest();
print("SUCCESS");

==> mongodb-src-r5.0.0.tar.gz: mongodb-src-r5.0.0/jstests/replsets/maintenance_non-blocking.js <==
// This test ensures that the replSetMaintenance command will not block, nor block-on, a db write
doTest = function() {
    "use strict";
    var replTest = new ReplSetTest({name: 'testSet', nodes: 2});
    var nodes = replTest.startSet();
    replTest.initiate();

    var m = replTest.getPrimary();
    var mColl = m.getDB("test").maint;
    var s = replTest.getSecondary();
    var sDB = s.getDB("test");
    var sColl = sDB.maint;

    // The default WC is majority and fsyncLock will prevent satisfying any majority writes.
    assert.commandWorked(replTest.getPrimary().adminCommand(
        {setDefaultRWConcern: 1, defaultWriteConcern: {w: 1}, writeConcern: {w: "majority"}}));

    var status = assert.commandWorked(sDB.adminCommand("replSetGetStatus"));
    printjson(status);

    print("******* fsyncLock'n secondary ************* ");
    s.getDB("admin").fsyncLock();

    // save some records
    var len = 100;
    for (var i = 0; i < len; ++i) {
        assert.commandWorked(mColl.save({a: i}));
    }

    print("******* replSetMaintenance called on secondary ************* ");
    assert.commandWorked(sDB.adminCommand("replSetMaintenance"));

    var hello = assert.commandWorked(sColl.runCommand("hello"));
    assert.eq(false, hello.isWritablePrimary);
    assert.eq(false, hello.secondary);

    print("******* writing to primary ************* ");
    assert.commandWorked(mColl.save({_id: -1}));
    assert.neq(null, mColl.findOne());

    var hello = assert.commandWorked(sColl.runCommand("hello"));
    assert.eq(false, hello.isWritablePrimary);
    assert.eq(false, hello.secondary);

    print("******* fsyncUnlock'n secondary ************* ");
    sDB.fsyncUnlock();

    print("******* unset replSetMaintenance on secondary ************* ");
    assert.commandWorked(sDB.adminCommand({replSetMaintenance: 0}));
    replTest.stopSet();
};

doTest();
print("SUCCESS");
